@@ -42,6 +42,7 @@
 #include <qwmatrix.h>
 #include <QBoxLayout>
 
+#include "core/ControlManager.h"
 #include "core/mixer.h"
 #include "gui/guiprofile.h"
 #include "gui/volumeslider.h"
@@ -602,6 +603,8 @@ VolumeSliderExtraData& MDWSlider::extraData(QAbstractSlider *slider)
   if ( sl2 ) return sl2->extraData;
   
   kError(67100) << "Invalid slider";
+//  char* foo = 0;
+//  char a = foo[3]; // Traceback ;)
   return MDWSlider::DummVolumeSliderExtraData;
 }
 
@@ -879,9 +882,9 @@ void MDWSlider::volumeChange( int )
 	m_view->blockSignals(oldViewBlockSignalState);
 }
 
-void MDWSlider::volumeChangeInternal( Volume& vol, QList<QAbstractSlider *>& ref_sliders  )
+void MDWSlider::volumeChangeInternal(Volume& vol, QList<QAbstractSlider *>& ref_sliders)
 {
-	if ( isStereoLinked() )
+	if (isStereoLinked())
 	{
 		QAbstractSlider* firstSlider = ref_sliders.first();
 		m_mixdevice->setMuted(false);
@@ -889,14 +892,14 @@ void MDWSlider::volumeChangeInternal( Volume& vol, QList<QAbstractSlider *>& ref
 	}
 	else
 	{
-		for( int i=0; i<ref_sliders.count(); i++ )
+		for (int i = 0; i < ref_sliders.count(); i++)
 		{
-		        if ( m_mixdevice->isMuted())
-		        {   // changing from muted state: unmute (the "if" above is actually superfluous)
+			if (m_mixdevice->isMuted())
+			{   // changing from muted state: unmute (the "if" above is actually superfluous)
 				m_mixdevice->setMuted(false);
 			}
 			QAbstractSlider *sliderWidget = ref_sliders[i];
-			vol.setVolume( extraData(sliderWidget).getChid() ,sliderWidget->value());
+			vol.setVolume(extraData(sliderWidget).getChid(), sliderWidget->value());
 		} // iterate over all sliders
 	}
 }
@@ -949,11 +952,19 @@ void MDWSlider::setDisabled()
 
 void MDWSlider::setDisabled( bool value )
 {
+	//  kDebug() << "disable #1: value=" << value;
 	if ( m_disabled!=value)
 	{
-		value ? hide() : show();
+	  kDebug() << "disable: value=" << value;
+	  //value ? hide() : show();
+	  setVisible(!value); // TODO Hiding via context menu does not work. Why???
 		m_disabled = value;
 		m_view->configurationUpdate();
+#ifdef __GNUC__
+#warning Hiding a slider via context menu is broken. hide() or setVisible(xyz) simply seems to do nothing.
+#endif
+		// announce() recreates everyting, but it does not get better.
+		//ControlManager::instance().announce(m_mixdevice->mixer()->id(), ControlChangeType::ControlList, QString("MDWSlider::setDisabled"));
 	}
 }
 
@@ -1011,9 +1022,9 @@ void MDWSlider::moveStream(QString destId)
  */
 void MDWSlider::update()
 {
-	  bool debugMe = (mixDevice()->id() == "PCM:0" );
-	  if (debugMe) kDebug() << "The update() PCM:0 playback state" << mixDevice()->isMuted()
-	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
+//	  bool debugMe = (mixDevice()->id() == "PCM:0" );
+//	  if (debugMe) kDebug() << "The update() PCM:0 playback state" << mixDevice()->isMuted()
+//	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
 
 	if ( m_slidersPlayback.count() != 0 || m_mixdevice->hasMuteSwitch() )
 		updateInternal(m_mixdevice->playbackVolume(), m_slidersPlayback, m_mixdevice->isMuted() );
@@ -1232,30 +1243,40 @@ bool MDWSlider::eventFilter( QObject* obj, QEvent* e )
 			increase = !increase;
 
 		Volume::VolumeTypeFlag volumeType = Volume::Playback;
-		QSlider *slider = static_cast<QSlider*>(obj);
+		QAbstractSlider *slider = qobject_cast<QAbstractSlider*>(obj);
 		if (slider != 0)
 		{
-			kDebug();
-			kDebug();
-			kDebug() << "----------------------------- Slider is " << slider;
+//			kDebug();
+//			kDebug();
+//			kDebug() << "----------------------------- Slider is " << slider;
 			// Mouse is over a slider. So lets apply the wheel event to playback or capture only
 			if(m_slidersCapture.contains(slider))
 			{
-				kDebug() << "Slider is capture " << slider;
+//				kDebug() << "Slider is capture " << slider;
 				volumeType = Volume::Capture;
 			}
 		}
+		else
+		{
+			// Mouse not over a slider => do a little guessing
+			if (!m_slidersPlayback.isEmpty())
+				slider = qobject_cast<QAbstractSlider*>(m_slidersPlayback.first());
+			else if (!m_slidersCapture.isEmpty())
+				slider = qobject_cast<QAbstractSlider*>(m_slidersCapture.first());
+			else
+				slider = 0;
+		}
 
 		increaseOrDecreaseVolume(!increase, volumeType);
-//		if (increase) {
-//			increaseVolume();
-//		}
-//		else {
-//			decreaseVolume();
-//		}
 		
-		Volume& volP = m_mixdevice->playbackVolume();
-		volumeValues.push_back(volP.getVolume(extraData((QAbstractSlider*)obj).getChid()));
+		if (slider != 0)
+		{
+			Volume& volP = m_mixdevice->playbackVolume();
+//			kDebug() << "slider=" << slider->objectName();
+			VolumeSliderExtraData& sliderExtraData = extraData(slider);
+//			kDebug() << "slider=" << slider->objectName() << "sliderExtraData=" << sliderExtraData.getSubcontrolLabel() << " , chid=" << sliderExtraData.getChid();
+			volumeValues.push_back(volP.getVolume(sliderExtraData.getChid()));
+		}
 		return true;
 	}
 	return QWidget::eventFilter(obj,e);
